<?php
session_start();
include 'db.php';

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

$user_id = $_SESSION['user_id'];

// Fetch available tasks that the user hasn't submitted yet
$sql_tasks = "SELECT * FROM tasks WHERE status = 'active' AND id NOT IN (SELECT task_id FROM task_submissions WHERE user_id = '$user_id')";
$tasks = $conn->query($sql_tasks);

// Fetch completed tasks with task titles
$sql_completed_tasks = "
    SELECT ts.*, t.title 
    FROM task_submissions ts 
    JOIN tasks t ON ts.task_id = t.id 
    WHERE ts.user_id = '$user_id' AND ts.status = 'approved'";
$completed_tasks = $conn->query($sql_completed_tasks);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Tasks</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">

    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .task-card {
            border-radius: 10px;
            border: 1px solid #ddd;
            margin-bottom: 20px;
            padding: 20px;
            background-color: #f8f9fa;
        }
        .task-title {
            font-size: 18px;
            font-weight: bold;
        }
        .btn-view-task {
            margin-top: 10px;
            font-size: 14px;
        }
        .submit-success {
            font-size: 18px;
            color: #28a745;
            text-align: center;
            padding: 10px;
            background-color: #e9f7ef;
            border-radius: 10px;
        }
        .completed-task-title {
            font-size: 16px;
            font-weight: bold;
            color: #343a40;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <h2 class="text-center">Available Tasks</h2>

        <?php if ($tasks->num_rows > 0): ?>
            <div id="taskList">
                <?php while ($task = $tasks->fetch_assoc()): ?>
                    <div class="task-card">
                        <div class="task-title"><?php echo $task['title']; ?></div>
                        <button class="btn btn-primary btn-view-task" data-bs-toggle="collapse" data-bs-target="#taskDetails<?php echo $task['id']; ?>">View Task</button>
                        <div id="taskDetails<?php echo $task['id']; ?>" class="collapse mt-3">
                            <p><?php echo $task['description']; ?></p>
                            <a href="<?php echo $task['link']; ?>" target="_blank" class="btn btn-success">Perform Task</a>
                            <form method="post" action="submit_task.php" enctype="multipart/form-data" class="mt-3">
                                <input type="hidden" name="task_id" value="<?php echo $task['id']; ?>">
                                <div class="mb-3">
                                    <label for="proof_image" class="form-label">Proof Image</label>
                                    <input type="file" class="form-control" name="proof_image" required>
                                </div>
                                <div class="mb-3">
                                    <label for="proof_text" class="form-label">Proof Description</label>
                                    <textarea class="form-control" name="proof_text" required></textarea>
                                </div>
                                <button type="submit" class="btn btn-success">Submit Task</button>
                            </form>
                        </div>
                    </div>
                <?php endwhile; ?>
            </div>
        <?php else: ?>
            <p>No tasks available at the moment.</p>
        <?php endif; ?>

        <h3 class="mt-5">Completed Tasks</h3>
        <?php if ($completed_tasks->num_rows > 0): ?>
            <ul class="list-group">
                <?php while ($task = $completed_tasks->fetch_assoc()): ?>
                    <li class="list-group-item">
                        <div class="completed-task-title"><?php echo $task['title']; ?></div>
                        <p>Status: <?php echo ucfirst($task['status']); ?></p>
                    </li>
                <?php endwhile; ?>
            </ul>
        <?php else: ?>
            <p>No tasks completed yet.</p>
        <?php endif; ?>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <script>
        function showSuccessMessage() {
            Swal.fire({
                title: 'Success!',
                text: 'Task has been successfully submitted!',
                icon: 'success',
                showConfirmButton: false,
                timer: 2000,
                backdrop: `
                    rgba(0, 123, 255, 0.4)
                    left top
                    no-repeat
                `,
            }).then(function() {
                window.location.reload(); // Refresh the page after the alert disappears
            });
        }

        // Check if the session variable is set and trigger the popup
        <?php if (isset($_SESSION['task_submitted'])): ?>
            showSuccessMessage();
            <?php unset($_SESSION['task_submitted']); // Unset the session variable ?>
        <?php endif; ?>
    </script>
<!-- Footer Navigation Menu -->
<div class="footer-nav bg-light fixed-bottom">
    <div class="container">
        <div class="row text-center">
            <div class="col-3">
                <a href="dashboard.php" class="nav-link active">
                    <i class="fas fa-home"></i>
                    <span>Dashboard</span>
                </a>
            </div>
            <div class="col-3">
                <a href="tasks.php" class="nav-link">
                    <i class="fas fa-tasks"></i>
                    <span>Tasks</span>
                </a>
            </div>
            <div class="col-3">
                <a href="withdrawals.php" class="nav-link">
                    <i class="fas fa-wallet"></i>
                    <span>Withdraw</span>
                </a>
            </div>
            <div class="col-3">
                <a href="daily_reward.php" class="nav-link">
                    <i class="fas fa-gift"></i>
                    <span class="shorten-text">Daily Reward</span>
                </a>
            </div>
        </div>
    </div>
</div>

<!-- CSS for the Footer Navigation -->
<style>
.footer-nav {
    padding: 10px 0;
    box-shadow: 0 -2px 5px rgba(0, 0, 0, 0.1);
    background: #fff;
    border-top: 1px solid #ddd;
}
.footer-nav .nav-link {
    color: #007bff;
    font-size: 16px;
    display: block;
    text-decoration: none;
    position: relative;
}
.footer-nav .nav-link i {
    display: block;
    font-size: 24px;
    margin-bottom: 5px;
}
.footer-nav .nav-link span {
    display: block;
    font-size: 12px;
}
.footer-nav .nav-link.active {
    color: #0056b3;
    font-weight: bold;
}
.footer-nav .nav-link.active i {
    color: #0056b3;
}
.footer-nav .shorten-text {
    display: inline-block;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    max-width: 80px; /* Adjust this value as needed */
}
</style>


</body>
</html>
